#! /bin/bash -e

# Copyright (c) 2007 Takahiro Shinozaki

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.


# Synopsis
#   proto.bash [-debug] [-c config]
# 
# Description:
#	initialize HMM model parameters

# Change log:
# Wed Dec 26 20:20:01 JST 2007
# The initial version was written by Takahiro Shinozaki.

[ -n "$debug" ] && set -x
scriptp=$0
script=`basename $0`

function usage {
    echo "Usage: $script [-debug]"
    echo "          [-config CONFIGURATION]"
    exit 1
}

# initialize local variables
doneflg=done
envlog=env.log

while [ -n "$1" ]; do
    case "$1" in
	-debug) shift; export debug=1; set -x;;
	-config) shift; export config=$1; shift; . $config;;
	*) usage;
    esac
done

if [ -f $doneflg ]; then
    echo "Nothing to be done ($script)."
    exit 0
fi

# dump environmental variables
env > $envlog

echo --$script START--
date
pwd
if [ ! -e $script ]; then
    cp -p $scriptp .
fi

# All the input global variables used in this script are (should be) listed here.
echo debug=$debug
echo config=$config
echo HCompV=$HCompV
echo scp=$scp
echo outdir=$outdir
echo proto0=$proto0
echo brun=$brun
echo bruncfg=$bruncfg

# check requirments
if [ "$HCompV" = "" ]; then echo HCompV is not defined; exit 1; fi
if [ "$scp" = "" ]; then echo scp is not defined; exit 1; fi
if [ "$proto0" = "" ]; then echo proto0 is not defined; exit 1; fi
if [ "$brun" = "" ]; then echo brun is not defined; exit 1; fi

if [ "$bruncfg" == "" ]; then
    brunopt=""
else
    brunopt="-c $bruncfg"
fi

mkdir -p $outdir

out=hcompv.out
err=hcompv.err
echo "$out $err \
      $HCompV -V -D -f 0.01 -m -S $scp -M $outdir $proto0" \
      >> brun

$brun $brunopt brun

touch done
echo --$script END--
